summaryrefslogtreecommitdiffstats
path: root/core/java/android/webkit/PluginStub.java
diff options
context:
space:
mode:
authorDerek Sollenberger <djsollen@google.com>2009-09-08 18:31:40 -0400
committerDerek Sollenberger <djsollen@google.com>2009-09-15 19:33:54 -0400
commit0b3a5d65247be1fb79d66af534fa78a94743864f (patch)
tree4528b972912c47ee3c8f3161a9b9ba32134b3a74 /core/java/android/webkit/PluginStub.java
parentd1d6778247d4b3798f9b9fafca4312a348826a0b (diff)
downloadframeworks_base-0b3a5d65247be1fb79d66af534fa78a94743864f.zip
frameworks_base-0b3a5d65247be1fb79d66af534fa78a94743864f.tar.gz
frameworks_base-0b3a5d65247be1fb79d66af534fa78a94743864f.tar.bz2
First pass at replacing native plugin views with java.
Change-Id: I6d1f45f31210c2353fa348cc37be8d91bcd5e887
Diffstat (limited to 'core/java/android/webkit/PluginStub.java')
-rw-r--r--core/java/android/webkit/PluginStub.java15
1 files changed, 6 insertions, 9 deletions
diff --git a/core/java/android/webkit/PluginStub.java b/core/java/android/webkit/PluginStub.java
index c24da8d..cbb36aa 100644
--- a/core/java/android/webkit/PluginStub.java
+++ b/core/java/android/webkit/PluginStub.java
@@ -19,32 +19,29 @@ import android.content.Context;
import android.view.View;
/**
* This abstract class is used to implement plugins in a WebView. A plugin
* package may extend this class and implement the abstract functions to create
* embedded or fullscreeen views displayed in a WebView. The PluginStub
* implementation will be provided the same NPP instance that is created
* through the native interface.
*/
-public abstract class PluginStub {
- /**
- * Construct a new PluginStub implementation for the given NPP instance.
- * @param npp The native NPP instance.
- */
- public PluginStub(int npp) { }
+public interface PluginStub {
/**
* Return a custom embedded view to draw the plugin.
+ * @param npp The native NPP instance.
* @param context The current application's Context.
* @return A custom View that will be managed by WebView.
*/
- public abstract View getEmbeddedView(Context context);
+ public abstract View getEmbeddedView(int NPP, Context context);
/**
* Return a custom full-screen view to be displayed when the user requests
* a plugin display as full-screen. Note that the application may choose not
* to display this View as completely full-screen.
+ * @param npp The native NPP instance.
* @param context The current application's Context.
* @return A custom View that will be managed by the application.
*/
- public abstract View getFullScreenView(Context context);
+ public abstract View getFullScreenView(int NPP, Context context);
}
@@ -19,32 +19,29 @@ import android.content.Context;
import android.view.View;
/**
- * This abstract class is used to implement plugins in a WebView. A plugin
+ * This interface is used to implement plugins in a WebView. A plugin
* package may extend this class and implement the abstract functions to create
* embedded or fullscreeen views displayed in a WebView. The PluginStub